@@ -11,32 +11,31 @@
 #include <QVariantList>
 #include <kcoreaddons_version.h>
 
+#include "device.h"
 #include "kdeconnectcore_export.h"
 #include "kdeconnectpluginconfig.h"
 #include "networkpacket.h"
-#include "device.h"
 
-#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5,44,0)
-#define K_PLUGIN_CLASS_WITH_JSON(classname,jsonFile) K_PLUGIN_FACTORY_WITH_JSON(classname ## Factory, jsonFile, registerPlugin<classname >();)
+#if KCOREADDONS_VERSION < QT_VERSION_CHECK(5, 44, 0)
+#define K_PLUGIN_CLASS_WITH_JSON(classname, jsonFile) K_PLUGIN_FACTORY_WITH_JSON(classname##Factory, jsonFile, registerPlugin<classname>();)
 #endif
 
 struct KdeConnectPluginPrivate;
 
-class KDECONNECTCORE_EXPORT KdeConnectPlugin
-    : public QObject
+class KDECONNECTCORE_EXPORT KdeConnectPlugin : public QObject
 {
     Q_OBJECT
 
 public:
-    KdeConnectPlugin(QObject* parent, const QVariantList& args);
+    KdeConnectPlugin(QObject *parent, const QVariantList &args);
     ~KdeConnectPlugin() override;
 
-    const Device* device();
-    Device const* device() const;
+    const Device *device();
+    Device const *device() const;
 
-    bool sendPacket(NetworkPacket& np) const;
+    bool sendPacket(NetworkPacket &np) const;
 
-    KdeConnectPluginConfig* config() const;
+    KdeConnectPluginConfig *config() const;
 
     virtual QString dbusPath() const;
 
@@ -47,7 +46,7 @@ public Q_SLOTS:
      * Returns true if it has handled the packet in some way
      * device.sendPacket can be used to send an answer back to the device
      */
-    virtual bool receivePacket(const NetworkPacket& np) = 0;
+    virtual bool receivePacket(const NetworkPacket &np) = 0;
 
     /**
      * This method will be called when a device is connected to this computer.
@@ -57,7 +56,6 @@ public Q_SLOTS:
 
 private:
     QScopedPointer<KdeConnectPluginPrivate> d;
-
 };
 
 #endif
